@@ -25,15 +25,18 @@
     #error "The file 'Rcpp.h' should not be included. Please correct to include only 'RcppArmadillo.h'."
 #endif
 
+// Deal with Armadillo 14.6.3 (fallback) versus 15.0.* (or later, preference) selection
+#include <RcppArmadillo/version/arma.h>
+
 // Set up actual #include <armadillo> after first #include <RcppArmadilloConfig> and more config
-#include <RcppArmadilloForward.h>
+#include <RcppArmadillo/interface/RcppArmadilloForward.h>
 
 // Now automatically include Rcpp as well
 #include <Rcpp.h>
 
 // Remaining RcppArmadillo code
-#include <RcppArmadilloWrap.h>
-#include <RcppArmadilloAs.h>
-#include <RcppArmadilloSugar.h>
+#include <RcppArmadillo/interface/RcppArmadilloWrap.h>
+#include <RcppArmadillo/interface/RcppArmadilloAs.h>
+#include <RcppArmadillo/interface/RcppArmadilloSugar.h>
 
 #endif
